@@ -14,17 +14,23 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+USA. */
 
 /* Written by Gordon Matzigkeit <gord@gnu.ai.mit.edu> */
 #include "foo.h"
 #include <stdio.h>
 
 int
-main (int argc, char **argv)
+main (argc, argv)
+     int argc;
+     char **argv;
 {
   printf ("Welcome to GNU Hell!\n");
 
+  /* Try assigning to the nothing variable */
+  nothing = 1;
+
   /* Just call the functions and check return values. */
   if (foo () != FOO_RET)
     return 1;
